// $Id: PropertyValueAccess.cs 10 2008-02-29 15:58:02Z mcartoixa $

/* ***************************************************************************
 *                                                                           *
 * Copyright  2007 NourY Solutions                                          *
 *                                                                           *
 * This file is part of DataRules.                                           *
 *                                                                           *
 * DataRules is free software; you can redistribute it and/or modify it      *
 * under the terms of the GNU Lesser General Public License as published     *
 * by the Free Software Foundation; either version 3 of the License, or      *
 * (at your option) any later version.                                       *
 *                                                                           *
 * DataRules is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of                *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU          *
 * Lesser General Public License for more details.                           *
 *                                                                           *
 * You should have received a copy of the GNU Lesser General Public          *
 * License along with this program.  If not, see                             *
 * <http://www.gnu.org/licenses/lgpl.html>.                                  *
 *                                                                           *
 *************************************************************************** */

/*! \file
 * \brief Definition of \c Salamanca.DataRules.ValidatorRule.
 *
 * \author $Author: mcartoixa $
 * \date $Date: 2008-02-29 16:58:02 +0100 (ven., 29 févr. 2008) $
 * \version $Revision: 10 $
 */

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Globalization;
using System.Reflection;
using System.Text;
using Microsoft.Practices.EnterpriseLibrary.Validation;
using Microsoft.Practices.EnterpriseLibrary.Validation.Integration;

namespace Salamanca.DataRules.EnterpriseLibrary
{

    internal sealed class PropertyValueAccess:
        ValueAccess
    {
        public PropertyValueAccess(PropertyInfo propertyInfo)
        {
            _PropertyInfo=propertyInfo;
        }

        public override bool GetValue(object source, out object value, out string valueAccessFailureMessage)
        {
            value=null;
            valueAccessFailureMessage=null;

            if (source==null)
            {
                valueAccessFailureMessage=string.Format(CultureInfo.CurrentUICulture, Salamanca.EnterpriseLibrary.SR.ErrorValueAccessNull, Key);
                return false;
            }

            if (!_PropertyInfo.DeclaringType.IsAssignableFrom(source.GetType()))
            {
                valueAccessFailureMessage=string.Format(
                    CultureInfo.CurrentUICulture,
                    Salamanca.EnterpriseLibrary.SR.ErrorValueAccessInvalidType,
                    this.Key,
                    source.GetType().FullName
                );
                return false;
            }

            value=_PropertyInfo.GetValue(source, null);
            return true;
        }

        public override string Key
        {
            get
            {
                return _PropertyInfo.Name;
            }
        }

        //internal PropertyInfo PropertyInfo
        //{
        //    get
        //    {
        //        return _PropertyInfo;
        //    }
        //}

        private PropertyInfo _PropertyInfo;

    }


    internal class PropertyValueAccessBuilder:
        MemberValueAccessBuilder
    {
        public PropertyValueAccessBuilder():
            base()
        {
        }

        protected override ValueAccess DoGetFieldValueAccess(FieldInfo fieldInfo)
        {
            throw new NotSupportedException();
        }

        protected override ValueAccess DoGetMethodValueAccess(MethodInfo methodInfo)
        {
            throw new NotSupportedException();
        }

        protected override ValueAccess DoGetPropertyValueAccess(PropertyInfo propertyInfo)
        {
            return new PropertyValueAccess(propertyInfo);
        }
    }

}
