﻿// $Id: CrudProviderHelper.cs 10 2008-02-29 15:58:02Z mcartoixa $
/*
 *  Copyright (C) 2007 NourY Solutions
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 3 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */
#pragma warning disable 1587
/** \file
 * \brief Definition of \c Salamanca.DataAccess.Web.CrudProviderHelper.
 *
 * \author $Author: mcartoixa $
 * \date $Date: 2008-02-29 16:58:02 +0100 (ven., 29 févr. 2008) $
 * \version $Revision: 10 $
 */
#pragma warning restore 1587

#if (!NET_CF)
using System;
using System.Collections;
using System.Collections.Generic;
using System.Text;

namespace Salamanca.DataAccess.Web
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Provides methods for web services oriented <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataMapper']/*" />s.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public static class CrudProviderHelper
    {

        /// <summary>Gets the array of <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" /> corresponding to
        /// the list of <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> returned by the specified <see cref="Finder{TDomainEntity}" />.</summary>
        /// <typeparam name="TDomainEntity">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> type.</typeparam>
        /// <typeparam name="TDomainEntityDataTransferObject">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" /> type.</typeparam>
        /// <param name="find">A delegate that returns a list of <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" />s.</param>
        /// <param name="dataMappers">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataMapper']/*" />s collection.</param>
        /// <returns>The array of <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" />.</returns>
        public static List<TDomainEntityDataTransferObject> DomainEntityFind<TDomainEntity, TDomainEntityDataTransferObject>(Finder<TDomainEntity> find, Collections.DataMapperCollection dataMappers)
            where TDomainEntity:
                IDomainEntity
            where TDomainEntityDataTransferObject:
                IDomainEntityDataTransferObject
        {
            ICollection<TDomainEntity> res=find();
            if (res!=null)
                return new List<TDomainEntity>(res).ConvertAll<TDomainEntityDataTransferObject>(
                    delegate(TDomainEntity m) {
                        return (TDomainEntityDataTransferObject)dataMappers[typeof(TDomainEntity)].GetData(m, true);
                    }
                );
            else
                return null;
        }



        /// <summary>Deletes the <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> corresponding to the specified 
        /// <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" /> with the specified <see cref="Deleter{TDomainEntity}" />.</summary>
        /// <typeparam name="TDomainEntity">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> type.</typeparam>
        /// <typeparam name="TDomainEntityDataTransferObject">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" /> type.</typeparam>
        /// <param name="data">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" />.</param>
        /// <param name="force">Indicates wheteher the deletion should be forced.</param>
        /// <param name="delete">A delegate that deletes a <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" />.</param>
        /// <param name="dataMappers">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataMapper']/*" />s collection.</param>
        /// <returns>The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" /> of the deleted <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" />.</returns>
        public static TDomainEntityDataTransferObject DomainEntityDelete<TDomainEntity, TDomainEntityDataTransferObject>(TDomainEntityDataTransferObject data, bool force, Deleter<TDomainEntity> delete, Collections.DataMapperCollection dataMappers)
            where TDomainEntity:
                IDomainEntity
            where TDomainEntityDataTransferObject:
                IDomainEntityDataTransferObject
        {
            TDomainEntity m=(TDomainEntity)dataMappers[typeof(TDomainEntity)].GetDomainEntity(data, dataMappers);
            delete(m, force);

            return (TDomainEntityDataTransferObject)dataMappers[typeof(TDomainEntity)].GetData(m, true);
        }



        /// <summary>Saves the <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> corresponding to the specified 
        /// <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" /> with the specified <see cref="Saver{TDomainEntity}" />.</summary>
        /// <typeparam name="TDomainEntity">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> type.</typeparam>
        /// <typeparam name="TDomainEntityDataTransferObject">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" /> type.</typeparam>
        /// <param name="data">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" />.</param>
        /// <param name="force">Indicates wheteher the save should be forced.</param>
        /// <param name="save">A delegate that saves a <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" />.</param>
        /// <param name="dataMappers">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataMapper']/*" />s collection.</param>
        /// <returns>The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataTransferObject']/*" /> of the saved <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" />.</returns>
        public static TDomainEntityDataTransferObject DomainEntitySave<TDomainEntity, TDomainEntityDataTransferObject>(TDomainEntityDataTransferObject data, bool force, Saver<TDomainEntity> save, Collections.DataMapperCollection dataMappers)
            where TDomainEntity:
                IDomainEntity
            where TDomainEntityDataTransferObject:
                IDomainEntityDataTransferObject
        {
            TDomainEntity m=(TDomainEntity)dataMappers[typeof(TDomainEntity)].GetDomainEntity(data, dataMappers);
            save(m, force);

            return (TDomainEntityDataTransferObject)dataMappers[typeof(TDomainEntity)].GetData(m, true);
        }



        /// <summary>Delegate that returns a list of <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" />s.</summary>
        /// <typeparam name="TDomainEntity">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> type.</typeparam>
        /// <returns>The list of <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" />s.</returns>
        public delegate IList<TDomainEntity> Finder<TDomainEntity>()
            where TDomainEntity:
                IDomainEntity;

        /// <summary>Delegate that deletes a <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" />.</summary>
        /// <typeparam name="TDomainEntity">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> type.</typeparam>
        /// <param name="m">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> to be deleted.</param>
        /// <param name="force">Indicates whether the deletion should be forced.</param>
        public delegate void Deleter<TDomainEntity>(TDomainEntity m, bool force)
            where TDomainEntity:
                IDomainEntity;

        /// <summary>Delegate that saves a <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" />.</summary>
        /// <typeparam name="TDomainEntity">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> type.</typeparam>
        /// <param name="m">The <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> to be saved.</param>
        /// <param name="force">Indicates whether the save should be forced.</param>
        public delegate void Saver<TDomainEntity>(TDomainEntity m, bool force)
            where TDomainEntity:
                IDomainEntity;
    }

}
#endif
