// $Id: DomainEntityDataSchemaImporterExtension.cs 10 2008-02-29 15:58:02Z mcartoixa $
/*
 *  Copyright (C) 2007 NourY Solutions
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 3 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */
#pragma warning disable 1587
/** \file
 * \brief Data object XML deserialization to original types.
 *
 * \author $Author: mcartoixa $
 * \date $Date: 2008-02-29 16:58:02 +0100 (ven., 29 févr. 2008) $
 * \version $Revision: 10 $
 */
#pragma warning restore 1587

#if (!NET_CF)
using System;
using System.CodeDom;
using System.CodeDom.Compiler;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.Reflection;
using System.Xml;
using System.Xml.Schema;
using System.Xml.Serialization;
using System.Xml.Serialization.Advanced;
using Salamanca.DataAccess;

namespace Salamanca.DataAccess.Web
{
    /// <summary>Permet de rcuprer les objets de donnes srialiss avec leur type original.</summary>
    public class DataTransferObjectSchemaImporterExtension:
        SchemaImporterExtension
    {

        /// <summary>Default constructor.</summary>
        public DataTransferObjectSchemaImporterExtension():
            base()
        {
            SoapReflectionImporter imp=new SoapReflectionImporter();
            foreach (Assembly a in AppDomain.CurrentDomain.GetAssemblies())
            {
                foreach (Type t in a.GetExportedTypes())
                {
                    bool dtoType=t.GetInterface(typeof(IDataTransferObject).FullName)!=null;

                    // We do not want to map every possible type
                    if (!dtoType && (!t.IsSerializable || t.IsAbstract || t.IsInterface || t.IsGenericTypeDefinition || t.IsPrimitive))
                        continue;

                    try
                    {
                        // Default mapping
                        XmlTypeMapping m=imp.ImportTypeMapping(t);
                        _Mappings.Add(m.XsdTypeName, m);

                        m=imp.ImportTypeMapping(t.MakeArrayType());
                        _Mappings.Add(m.XsdTypeName, m);

                        // Data Transfer Objects
                        if (dtoType)
                        {
                            Type tmp=typeof(DomainEntityDataTransferObject<>).MakeGenericType(t);
                            m=imp.ImportTypeMapping(tmp);
                            _Mappings.Add(m.XsdTypeName, m);

                            tmp=tmp.MakeArrayType();
                            m=imp.ImportTypeMapping(tmp);
                            _Mappings.Add(m.XsdTypeName, m);
                        }
                    } catch
                    {
                        // If a type has a public property that implements IDictionary, the SoapReflectionImporter will miserably fail...
                    }
                }
            }
        }

        /// <summary>This member supports the DataAccess infrastructure and is not intended to be used directly from your code.</summary>
        /// <param name="name">The name of the element.</param>
        /// <param name="ns">The namespace of the element.</param>
        /// <param name="context">An <see cref="XmlSchemaObject" /> that represents schema information, such as the line number of the XML element.</param>
        /// <param name="schemas">An <see cref="XmlSchemas" /> that contains the collection of schemas in the document.</param>
        /// <param name="importer">The <see cref="XmlSchemaImporter" /> that is the importer being used.</param>
        /// <param name="compileUnit">A <see cref="CodeCompileUnit" /> to which you can add CodeDOM structures to generate alternative code for the XSD.</param>
        /// <param name="mainNamespace">A <see cref="CodeNamespace" /> that represents the current namespace for the element.</param>
        /// <param name="options">A <see cref="CodeGenerationOptions" /> for the setting options on the code compiler.</param>
        /// <param name="codeProvider">A <see cref="CodeDomProvider" /> that is used to generate the new code.</param>
        /// <returns>The name of the CLR type that this maps to.</returns>
        public override string ImportSchemaType(string name, string ns, XmlSchemaObject context, XmlSchemas schemas, XmlSchemaImporter importer, CodeCompileUnit compileUnit, CodeNamespace mainNamespace, CodeGenerationOptions options, CodeDomProvider codeProvider)
        {
            string ret=null;

            XmlTypeMapping m;
            if (_Mappings.TryGetValue(name, out m))
            {
                ret=m.TypeFullName;
            } else
                ret=base.ImportSchemaType(name, ns, context, schemas, importer, compileUnit, mainNamespace, options, codeProvider);

            return ret;
        }

        private Dictionary<string, XmlTypeMapping> _Mappings=new Dictionary<string, XmlTypeMapping>();
    }
}
#endif
