// $Id: Question.cs 10 2008-02-29 15:58:02Z mcartoixa $
/*
 *  Copyright (C) 2007 NourY Solutions
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 3 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */
/*! \file
 * \brief Definition of \c Salamanca.DataActivities.UI.Question.
 *
 * \author $Author: mcartoixa $
 * \date $Date: 2008-02-29 16:58:02 +0100 (ven., 29 fvr. 2008) $
 * \version $Revision: 10 $
 */

#if (!NET_CF)
using System;
using System.Collections.Generic;
using System.Text;
using System.Web;
using System.Web.UI;

namespace Salamanca.DataActivities.UI.Web
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Question implemented as a <see cref="IHttpHandler" />.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public class HttpHandlerQuestion:
        Question
    {

        /// <summary>Initializes a new <see cref="HttpHandlerQuestion" /> class.</summary>
        public HttpHandlerQuestion(string path)
        {
            _Path=path;
        }

        /// <summary>Initializes a new <see cref="HttpHandlerQuestion" /> class.</summary>
        public HttpHandlerQuestion(IHttpHandler handler)
        {
            _Handler=handler;
            _Path=HttpContext.Current.Request.Path;
        }

        /// <summary>Raises the <see cref="Question.Initialized" /> event.</summary>
        protected override void OnInitialized(QuestionEventArgs e)
        {
            if (HttpContext.Current.Server.MapPath(HttpContext.Current.Request.Path)!=HttpContext.Current.Server.MapPath(_Path))
                HttpContext.Current.Response.Redirect(_Path);

            if (_Handler==null)
                _Handler=HttpContext.Current.Handler;

            base.OnInitialized(e);
        }

        /// <summary>Asks the question.</summary>
        public override ActivityStateResult Ask(IActivityController controller)
        {
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the <see cref="IHttpHandler" /> associated to this question.</summary>
        protected IHttpHandler Handler
        {
            get
            {
                return _Handler;
            }
        }

        private IHttpHandler _Handler;
        private string _Path;
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Question implemented as a <see cref="IHttpHandler" />.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public class HttpHandlerQuestion<TAnswer>:
        HttpHandlerQuestion
    {

        /// <summary>Initializes a new <see cref="HttpHandlerQuestion" /> class.</summary>
        public HttpHandlerQuestion(string path):
            base(path)
        {
        }

        /// <summary>Initializes a new <see cref="HttpHandlerQuestion" /> class.</summary>
        public HttpHandlerQuestion(IHttpHandler handler):
            base(handler)
        {
        }

        /// <summary>Raises the <see cref="Question.Initialized" /> event.</summary>
        protected override void OnInitialized(QuestionEventArgs e)
        {
            base.OnInitialized(e);

            IDataBag<TAnswer> handler=Handler as IDataBag<TAnswer>;
            IDataBag<TAnswer> data=e.Controller.CurrentState.Data as IDataBag<TAnswer>;
            if ((handler!=null)&&(data!=null))
                handler.Data=data.Data;
        }

        /// <summary>Raises the <see cref="Question.Answering" /> event.</summary>
        protected override void OnAnswering(AnswerEventArgs e)
        {
            base.OnAnswering(e);

            IAnswerContainer<TAnswer> handler=Handler as IAnswerContainer<TAnswer>;
            IDataBag<TAnswer> data=e.Data as IDataBag<TAnswer>;
            if (handler!=null)
            {
                e.Answer=handler.Answer;
                if (data!=null)
                    data.Data=handler.Answer;
            }
        }

    }
}
#endif
