// $Id: AnswerController.cs 10 2008-02-29 15:58:02Z mcartoixa $
/*
 *  Copyright (C) 2007 NourY Solutions
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 3 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */
/*! \file
 * \brief Definition of \c Salamanca.DataActivities.UI.Forms.AnswerController.
 *
 * \author $Author: mcartoixa $
 * \date $Date: 2008-02-29 16:58:02 +0100 (ven., 29 févr. 2008) $
 * \version $Revision: 10 $
 */

using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using System.Windows.Forms;

namespace Salamanca.DataActivities.UI.Forms
{




    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Non visual control that helps define the default behavior for activity related controls.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    //    [SRDescription("DescriptionErrorProvider")]
    [ToolboxItemFilter("System.Windows.Forms")]
    [ProvideProperty("CancelControl", typeof(Control))]
    [ProvideProperty("EndControl", typeof(Control))]
    [ProvideProperty("NextControl", typeof(Control))]
    [ProvideProperty("PreviousControl", typeof(Control))]
    public class AnswerController:
        Component,
        IExtenderProvider
    {
        private class Properties
        {
            public Control CancelControl;
            public Control EndControl;
            public Control NextControl;
            public Control PreviousControl;
        }

        /// <summary>Initializes a new instance of the <see cref="AnswerController" /> class.</summary>
        public AnswerController()
        {
        }

        /// <summary>Initializes a new instance of the <see cref="AnswerController" /> class.</summary>
        /// <param name="container">The container.</param>
        public AnswerController(IContainer container)
        {
            container.Add(this);
        }

        /// <summary>Specifies whether this object can provide its extender properties to the specified object.</summary>
        public bool CanExtend(object extendee)
        {
            Control c=extendee as Control;
            return ((c!=null) && (c.CausesValidation) && (!(extendee is Form)));
        }

        /// <summary>Gets the <see cref="Control" /> that triggers the cancellation of the current activity.</summary>
        [DefaultValue(null)]
        [SRCategory("Category_Activity")]
        public Control GetCancelControl(Control c)
        {
            return GetProperties(c).CancelControl;
        }

        /// <summary>Defines the <see cref="Control" /> that will trigger the cancellation of the current activity.</summary>
        public void SetCancelControl(Control c, Control value)
        {
            GetProperties(c).CancelControl=value;
        }

        /// <summary>Gets the <see cref="Control" /> that triggers the termination of the current activity.</summary>
        [DefaultValue(null)]
        [SRCategory("Category_Activity")]
        public Control GetEndControl(Control c)
        {
            return GetProperties(c).EndControl;
        }

        /// <summary>Defines the <see cref="Control" /> that will trigger the termination of the current activity.</summary>
        public void SetEndControl(Control c, Control value)
        {
            GetProperties(c).EndControl=value;
        }

        /// <summary>Gets the <see cref="Control" /> that triggers the continuation of the current activity.</summary>
        [DefaultValue(null)]
        [SRCategory("Category_Activity")]
        public Control GetNextControl(Control c)
        {
            return GetProperties(c).NextControl;
        }

        /// <summary>Defines the <see cref="Control" /> that will trigger the continuation of the current activity.</summary>
        public void SetNextControl(Control c, Control value)
        {
            GetProperties(c).NextControl=value;
        }

        /// <summary>Gets the <see cref="Control" /> that is triggers the stepping back of the current activity.</summary>
        [DefaultValue(null)]
        [SRCategory("Category_Activity")]
        public Control GetPreviousControl(Control c)
        {
            return GetProperties(c).PreviousControl;
        }

        /// <summary>Defines the <see cref="Control" /> that will trigger the stepping back of the current activity.</summary>
        public void SetPreviousControl(Control c, Control value)
        {
            GetProperties(c).PreviousControl=value;
        }

        private Properties GetProperties(Control c)
        {
            Properties ret=null;

            if (!_Properties.TryGetValue(c, out ret))
            {
                ret=new Properties();
                _Properties.Add(c, ret);
                c.Disposed+=new EventHandler(
                    delegate(object sender, EventArgs e) {
                        _Properties.Remove(c);
                    }
                );
            }

            return ret;
        }

        private static Dictionary<Control, Properties> _Properties=new Dictionary<Control, Properties>();

    }
}
