﻿// $Id: QuestionProvider.cs 10 2008-02-29 15:58:02Z mcartoixa $
/*
 *  Copyright (C) 2007 NourY Solutions
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 3 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */
/*! \file
 * \brief Definition of \c Salamanca.DataActivities.UI.Forms.QuestionProvider.
 *
 * \author $Author: mcartoixa $
 * \date $Date: 2008-02-29 16:58:02 +0100 (ven., 29 févr. 2008) $
 * \version $Revision: 10 $
 */

using System;
using System.ComponentModel;
using System.ComponentModel.Design;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing.Design;
using System.Text;
using System.Windows.Forms;

namespace Salamanca.DataActivities.UI.Forms
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Non visual control that helps create <see cref="Question" />s from <see cref="Control" />s on a <see cref="Form" />.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    [ToolboxItemFilter("System.Windows.Forms")]
    [ProvideProperty("QuestionName", typeof(Control))]
    public class QuestionProvider:
        Component,
        IExtenderProvider
    {
        private class Properties
        {
            public string QuestionName;
        }

        /// <summary>Initializes a new instance of the <see cref="QuestionProvider" /> class.</summary>
        public QuestionProvider()
        {
        }

        /// <summary>Initializes a new instance of the <see cref="QuestionProvider" /> class.</summary>
        public QuestionProvider(IContainer container)
        {
            container.Add(this);
        }

        /// <summary>Specifies whether this object can provide its extender properties to the specified object.</summary>
        public bool CanExtend(object extendee)
        {
            Control c=extendee as Control;
            return ((c!=null) && (c.CausesValidation) && (!(extendee is Form)));
        }

        /// <summary>Gets the name of the question associated to the specified control.</summary>
        [DefaultValue(null)]
        [SRCategory("Category_Activity")]
        public string GetQuestionName(Control c)
        {
            return GetProperties(c).QuestionName;
        }

        /// <summary>Sets the name of the question associated to the specified control.</summary>
        public void SetQuestionName(Control c, string value)
        {
            GetProperties(c).QuestionName=value;
        }

        //public Control GetControl(Form form, string questionName)
        //{
        //    foreach (KeyValuePair<Control, Properties> kvp in _Properties)
        //    {
        //        if (kvp.Key.CanFocus && (kvp.Key.FindForm()==form))
        //            if (
        //                Array.Exists<string>(
        //                    kvp.Value.QuestionNames,
        //                    new Predicate<string>(
        //                        delegate(string n) {
        //                            return n==name;
        //                        }
        //                    )
        //                )
        //            )
        //                return kvp.Key;
        //    }

        //    return null;
        //}

        private Properties GetProperties(Control c)
        {
            Properties ret=null;

            if (!_Properties.TryGetValue(c, out ret))
            {
                ret=new Properties();
                _Properties.Add(c, ret);
                c.Disposed+=new EventHandler(
                    delegate(object sender, EventArgs e) {
                        _Properties.Remove(c);
                    }
                );
            }

            return ret;
        }

        private static Dictionary<Control, Properties> _Properties=new Dictionary<Control, Properties>();

    }
}
