// $Id: Collection.cs 10 2008-02-29 15:58:02Z mcartoixa $
/*
 *  Copyright (C) 2007 NourY Solutions
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 3 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */
/*! \file
 * \brief Definition of Domain Entity collections.
 *
 * \author $Author: mcartoixa $
 * \date $Date: 2008-02-29 16:58:02 +0100 (ven., 29 févr. 2008) $
 * \version $Revision: 10 $
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Diagnostics;

namespace Salamanca.DataAccess.Collections
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Implements a read-only <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> collection.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public class ReadOnlyDomainEntityCollection<TDomainEntity>:
        ReadOnlyCollection<TDomainEntity>
        where TDomainEntity:
            IDomainEntity
    {

        /// <summary>Initializes a new instance of the <see cref="ReadOnlyDomainEntityCollection{TDomainEntity}" /> class that is a read-only wrapper around the specified list.</summary>
        /// <param name="list">The list to wrap.</param>
        public ReadOnlyDomainEntityCollection(IList<TDomainEntity> list):
            base(list)
        {
        }

    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Implements a  <include file="../../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> collection.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public class DomainEntityCollection<TDomainEntity>:
        Collection<TDomainEntity>
        where TDomainEntity:
            IDomainEntity
    {

        /// <summary>Initializes a new instance of the <see cref="DomainEntityCollection{TDomainEntity}" /> class.</summary>
        public DomainEntityCollection():
            base()
        {
        }

        /// <summary>Initializes a new instance of the <see cref="DomainEntityCollection{TDomainEntity}" /> class as a wrapper around the specified list.</summary>
        /// <param name="list">The list to wrap.</param>
        public DomainEntityCollection(IList<TDomainEntity> list):
            base(list)
        {
        }

    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Implements a <include file="../../doc/Global.doc.xml" path="doc/template[@name='DataMapper']/*" /> collection.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public class DataMapperCollection:
        Dictionary<Type, IDataMapper>
    {

        /// <summary>Initializes a new instance of the <see cref="DataMapperCollection" /> class.</summary>
        public DataMapperCollection():
            this(new PersistenceContextProvider())
        {
        }

        /// <summary>Initializes a new instance of the <see cref="DataMapperCollection" /> class.</summary>
        public DataMapperCollection(IPersistenceContextProvider provider):
            base()
        {
            _Provider=provider;
        }

        internal IPersistenceContext CreatePersistenceContext()
        {
            return _Provider.CreatePersistenceContext();
        }

        internal IPersistenceContext CreatePersistenceContext(bool forceAction)
        {
            return _Provider.CreatePersistenceContext(forceAction);
        }

        /// <summary>Gets or sets the <see cref="PersistenceContextProvider" /> instance.</summary>
        public IPersistenceContextProvider PersistenceContextProvider
        {
            get
            {
                return _Provider;
            }
            set
            {
                _Provider=value;
            }
        }

        private IPersistenceContextProvider _Provider;
    }
}
