// $Id: ObservableCollection.cs 10 2008-02-29 15:58:02Z mcartoixa $
/*
 *  Copyright (C) 2007 NourY Solutions
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 3 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */
/*! \file
 * \brief Definition of Domain Entity observable collections.
 *
 * \author $Author: mcartoixa $
 * \date $Date: 2008-02-29 16:58:02 +0100 (ven., 29 févr. 2008) $
 * \version $Revision: 10 $
 */

#if (NET_3_0 || NET_3_5)
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Diagnostics;

namespace Salamanca.DataAccess.Collections
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Implements a read-only observable <include file="../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> collection.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public class ReadOnlyDomainEntityObservableCollection<TDomainEntity>:
        ReadOnlyObservableCollection<TDomainEntity>
        where TDomainEntity:
            IDomainEntity
    {

        /// <summary>Initializes a new instance of the <see cref="ReadOnlyDomainEntityObservableCollection{TDomainEntity}" /> class that is a read-only wrapper around the specified <see cref="DomainEntityObservableCollection{TDomainEntity}" />.</summary>
        /// <param name="list">The <see cref="DomainEntityObservableCollection{TDomainEntity}" /> to wrap.</param>
        public ReadOnlyDomainEntityObservableCollection(DomainEntityObservableCollection<TDomainEntity> list):
            base(list)
        {
        }

    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Implements an observable <include file="../doc/Global.doc.xml" path="doc/template[@name='DomainEntity']/*" /> collection.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public class DomainEntityObservableCollection<TDomainEntity>:
        ObservableCollection<TDomainEntity>
        where TDomainEntity:
            IDomainEntity
    {

        /// <summary>Initializes a new instance of the <see cref="DomainEntityObservableCollection{TDomainEntity}" /> class.</summary>
        public DomainEntityObservableCollection():
            base()
        {
        }

        /// <summary>Initializes a new instance of the <see cref="DomainEntityObservableCollection{TDomainEntity}" /> class that contains elements copied from the specified list.</summary>
        /// <param name="list">The list from which the elements are copied.</param>
        public DomainEntityObservableCollection(List<TDomainEntity> list):
            base(list)
        {
        }

    }



}
#endif
