// $Id: DataMapper.cs 10 2008-02-29 15:58:02Z mcartoixa $
/*
 *  Copyright (C) 2007 NourY Solutions
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 3 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */
/*! \file
 * \brief Implementation of disposable collections.
 *
 * \author $Author: mcartoixa $
 * \date $Date: 2008-02-29 16:58:02 +0100 (ven., 29 fvr. 2008) $
 * \version $Revision: 10 $
 */

using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Data;
using Salamanca.Collections;

namespace Salamanca.DataAccess.Data
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Implements a read-only collection of <see cref="IDataReader" /> items.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public class ReadOnlyDataReaderCollection<TDataReader>:
        ReadOnlyDisposableCollection<TDataReader>
        where TDataReader:
            IDataReader
    {

        /// <summary>Initializes a new instance of the <see cref="ReadOnlyDataReaderCollection{TDataReader}" /> class that is a read-only wrapper around the specified list.</summary>
        /// <param name="list">The list to wrap.</param>
        public ReadOnlyDataReaderCollection(IList<TDataReader> list):
            base(list)
        {
        }



        /// <summary>Advances the <see cref="IDataReader" /> items to the next record.</summary>
        /// <returns><c>true</c> if there are more rows; otherwise, <c>false</c>.</returns>
        public bool Read()
        {
            bool ret=true;

            foreach (IDataReader reader in this)
                ret&=reader.Read();

            return ret;
        }



        /// <summary>Gets a read-only collection of <see cref="IDataRecord" /> items.</summary>
        public IList<IDataRecord> DataRecords
        {
            get
            {
                return new ReadOnlyCollection<IDataRecord>(
                    new List<TDataReader>(this)
                        .ConvertAll<IDataRecord>(
                            delegate(TDataReader reader) {
                                return (IDataRecord)reader;
                            }
                        )
                );
            }
        }

    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Implements a collection of <see cref="IDataReader" /> items.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public class DataReaderCollection<TDataReader>:
        DisposableCollection<TDataReader>
        where TDataReader:
            IDataReader
    {

        /// <summary>Initializes a new instance of the <see cref="DataReaderCollection{TDataReader}" /> class.</summary>
        public DataReaderCollection():
            base()
        {
        }

        /// <summary>Initializes a new instance of the <see cref="DataReaderCollection{TDataReader}" /> class that is a wrapper around the specified list.</summary>
        /// <param name="list">The list to wrap.</param>
        public DataReaderCollection(IList<TDataReader> list):
            base(list)
        {
        }



        /// <summary>Advances the <see cref="IDataReader" /> items to the next record.</summary>
        /// <returns><c>true</c> if there are more rows; otherwise, <c>false</c>.</returns>
        public bool Read()
        {
            bool ret=true;

            foreach (IDataReader reader in this)
                ret&=reader.Read();

            return ret;
        }



        /// <summary>Gets a read-only collection of <see cref="IDataRecord" /> items.</summary>
        public IList<IDataRecord> DataRecords
        {
            get
            {
                return new ReadOnlyCollection<IDataRecord>(
                    new List<TDataReader>(this)
                        .ConvertAll<IDataRecord>(
                            delegate(TDataReader reader) {
                                return (IDataRecord)reader;
                            }
                        )
                );
            }
        }

    }
}
