// $Id: CompositeActivityState.cs 10 2008-02-29 15:58:02Z mcartoixa $
/*
 *  Copyright (C) 2007 NourY Solutions
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 3 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */
/*! \file
 * \brief Definition of \c Salamanca.DataActivities.CompositeActivityState.
 *
 * \author $Author: mcartoixa $
 * \date $Date: 2008-02-29 16:58:02 +0100 (ven., 29 fvr. 2008) $
 * \version $Revision: 10 $
 */

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Globalization;
using System.Text;
using Salamanca.DataRules;

namespace Salamanca.DataActivities.UI
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Interface of an activity state that asks a question.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public interface IQuestionActivityState:
        IActivityState
    {

        /// <summary>Gets or sets the question asked by the state.</summary>
        IQuestion Question
        {
            get;
            set;
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Base implementation of an activity state that asks a question.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public abstract class QuestionActivityState<TActivityData>:
        ActivityState<TActivityData>,
        IQuestionActivityState
        where TActivityData:
            IActivityData
    {

        /// <summary>Initializes a new <see cref="QuestionActivityState{TActivityData}" /> instance.</summary>
        protected QuestionActivityState(TActivityData data):
            base(data)
        {
        }

        /// <summary>Initializes a new <see cref="QuestionActivityState{TActivityData}" /> instance.</summary>
        protected QuestionActivityState(TActivityData data, IActivityParameters parameters):
            base(data, parameters)
        {
        }

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Terminated" /> event.</summary>
        protected override void OnTerminated(ActivityStateEventArgs e)
        {
            Question.Terminate(e.Controller);

            base.OnTerminated(e);
        }

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        protected override void OnInitialized(ActivityStateEventArgs e)
        {
            base.OnInitialized(e);

            Question.Initialize(e.Controller);
        }

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Validating" /> event.</summary>
        protected override void OnValidating(ValidationEventArgs e)
        {
            base.OnValidating(e);

            Question.Answer(null, Data);
        }

        /// <summary>Asks the <see cref="Question" />.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Question.Ask(controller);
        }

        /// <summary>Gets the question asked by the state.</summary>
        protected IQuestion Question
        {
            get
            {
                return _Question;
            }
            set
            {
                _Question=value;
            }
        }

        /// <summary>Gets or sets the question asked by the state.</summary>
        IQuestion IQuestionActivityState.Question
        {
            get
            {
                return Question;
            }
            set
            {
                Question=value;
            }
        }

        /// <summary>The question asked by the state.</summary>
        private IQuestion _Question;
    }

}
