// $Id: DomainEntity.cs 10 2008-02-29 15:58:02Z mcartoixa $
/*
 *  Copyright (C) 2007 NourY Solutions
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 3 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library. If not, see <http://www.gnu.org/licenses/>.
 *
 */

using System;
using System.Collections.Generic;
using System.Data;
using System.Diagnostics;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Salamanca.DataAccess;
using Northwind;
using Northwind.DomainModel;
using Northwind.DomainModel.Data;

namespace Salamanca.NUnit.DataAccess.Northwind.Data
{
    public abstract class DataDomainEntityBase:
        DomainEntityBase
    {

        [TestInitialize]
        public void SetUp()
        {
            _Db=CreateDb();
            _Cache=CreateCacheManager();

            Mappers=global::Northwind.DomainModel.Data.Mappers.CreateDataMapperCollection(_Db.Connection, _Cache);
            switch (_Db.DatabaseType)
            {
            case NorthwindDatabaseType.Access:
            //case NorthwindDatabaseType.SqlCompact:
            case NorthwindDatabaseType.SQLite:
                Mappers.PersistenceContextProvider=new Salamanca.DataAccess.Data.PersistenceContextProvider(_Db.Connection);
                break;
            }
        }

        [TestCleanup]
        public void TearDown()
        {
            Customer.IdentityMap.Clear();
            Employee.IdentityMap.Clear();
            Order.IdentityMap.Clear();
            OrderDetails.IdentityMap.Clear();
            if (_Cache!=null)
                _Cache.Clear();

            _Db.Dispose();
        }

        protected abstract NorthwindDb CreateDb();
        protected abstract ICacheManager CreateCacheManager();

        private NorthwindDb _Db;
        private ICacheManager _Cache;
    }

    [TestClass]
    public class AccessDomainEntityWithOpenedConnectionFixture:
        DataDomainEntityBase
    {
        protected override NorthwindDb CreateDb()
        {
            NorthwindDb ret=new NorthwindDb(NorthwindDatabaseType.Access);
            ret.Connection.Open();
            return ret;
        }

        protected override ICacheManager CreateCacheManager()
        {
            return null;
        }
    }

    [TestClass]
    public class AccessDomainEntityFixture:
        DataDomainEntityBase
    {
        protected override NorthwindDb CreateDb()
        {
            return new NorthwindDb(NorthwindDatabaseType.Access);
        }

        protected override ICacheManager CreateCacheManager()
        {
            return null;
        }
    }

    [TestClass]
    public class AccessNoCacheDomainEntityFixture:
        AccessDomainEntityFixture
    {
        protected override ICacheManager CreateCacheManager()
        {
            return new NoCacheManager();
        }

    }

    [TestClass]
    public class SqlClientDomainEntityWithOpenedConnectionFixture:
        DataDomainEntityBase
    {
        protected override NorthwindDb CreateDb()
        {
            NorthwindDb ret=new NorthwindDb(NorthwindDatabaseType.SqlClient);
            ret.Connection.Open();
            return ret;
        }

        protected override ICacheManager CreateCacheManager()
        {
            return null;
        }
    }

    [TestClass]
    public class SqlClientDomainEntityFixture:
        DataDomainEntityBase
    {
        protected override NorthwindDb CreateDb()
        {
            return new NorthwindDb(NorthwindDatabaseType.SqlClient);
        }

        protected override ICacheManager CreateCacheManager()
        {
            return null;
        }
    }

    [TestClass]
    public class SqlClientNoCacheDomainEntityFixture:
        SqlClientDomainEntityFixture
    {
        protected override ICacheManager CreateCacheManager()
        {
            return new NoCacheManager();
        }

    }

    //[TestClass]
    //[Category("SqlCompact")]
    //public class SqlCompactDomainEntityWithOpenedConnectionFixture:
    //    DataDomainEntityBase
    //{
    //    protected override NorthwindDb CreateDb()
    //    {
    //        NorthwindDb ret=new NorthwindDb(NorthwindDatabaseType.SqlCompact);
    //        ret.Connection.Open();
    //        return ret;
    //    }

    //    protected override ICacheManager CreateCacheManager()
    //    {
    //        return null;
    //    }
    //}

    //[TestClass]
    //[Category("SqlCompact")]
    //public class SqlCompactDomainEntityFixture:
    //    DataDomainEntityBase
    //{
    //    protected override NorthwindDb CreateDb()
    //    {
    //        return new NorthwindDb(NorthwindDatabaseType.SqlCompact);
    //    }

    //    protected override ICacheManager CreateCacheManager()
    //    {
    //        return null;
    //    }
    //}

    //[TestClass]
    //[Category("SqlCompact")]
    //public class SqlCompactNoCacheDomainEntityFixture:
    //    SqlCompactDomainEntityFixture
    //{
    //    protected override ICacheManager CreateCacheManager()
    //    {
    //        return new NoCacheManager();
    //    }

    //}

    [TestClass]
    public class SqLiteDomainEntityWithOpenedConnectionFixture:
        DataDomainEntityBase
    {
        protected override NorthwindDb CreateDb()
        {
            NorthwindDb ret=new NorthwindDb(NorthwindDatabaseType.SQLite);
            ret.Connection.Open();
            return ret;
        }

        protected override ICacheManager CreateCacheManager()
        {
            return null;
        }
    }

    [TestClass]
    public class SqLiteDomainEntityFixture:
        DataDomainEntityBase
    {
        protected override NorthwindDb CreateDb()
        {
            return new NorthwindDb(NorthwindDatabaseType.SQLite);
        }

        protected override ICacheManager CreateCacheManager()
        {
            return null;
        }
    }
}
