//$Id$

using System;
using System.Collections.Generic;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    partial interface ICategoryCrudQuestionFactory
    {

        /// <summary>Gets a question about a <see cref="DomainModel.Category" /> instance.</summary>
        Question AskCategoryInfos(ActivityController controller, DomainModel.Category domainModel);
    }



    partial class CategoryCreate<TActivityData>
    {

        /// <summary>Performs the actual initialization of a new <see cref="DomainModel.Category" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Category=new DomainModel.Category(((IDataActivityParameters)Parameters).DataMappers);
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class CategoryAskInfos<TActivityData, TQuestionFactory>
    {

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        private void _OnInitialized(ActivityStateEventArgs e)
        {
            Question=((IQuestionFactoryParameters<TQuestionFactory>)Parameters).QuestionFactory.AskCategoryInfos((ActivityController)e.Controller, Data.Category);
            base.OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class CategorySave<TActivityData>
    {

        /// <summary>Performs the actual saving of the <see cref="DomainModel.Category" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Category.Save();
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class CategoryDelete<TActivityData>
    {

        /// <summary>Performs the actual deletion of the <see cref="DomainModel.Category" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Category.Delete();
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }

}
