﻿// $Id$

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Interface implemented by a class that acts as a <see cref="DomainModel.Category" /> question factory.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial interface ICategoryCrudQuestionFactory
    {
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that initializes a new <see cref="DomainModel.Category" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class CategoryCreate<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ICategoryContainer
    {

        /// <summary>Initializes a new instance of the <see cref="CategoryCreate{TActivityData}" /> class.</summary>
        public CategoryCreate(TActivityData data, IDataActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="CategoryCreate{TActivityData}" /> class.</summary>
        public CategoryCreate(TActivityData data, IDataActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual initialization of a new <see cref="Category" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that asks information about a <see cref="DomainModel.Category" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class CategoryAskInfos<TActivityData, TQuestionFactory>:
        QuestionActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ICategoryContainer
        where TQuestionFactory:
            ICategoryCrudQuestionFactory
    {

        /// <summary>Initializes a new instance of the <see cref="CategoryAskInfos{TActivityData}" /> class.</summary>
        public CategoryAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="CategoryAskInfos{TActivityData}" /> class.</summary>
        public CategoryAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        protected override void OnInitialized(ActivityStateEventArgs e)
        {
            _OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that saves a <see cref="DomainModel.Category" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class CategorySave<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ICategoryContainer
    {

        /// <summary>Initializes a new instance of the <see cref="CategorySave{TActivityData}" /> class.</summary>
        public CategorySave(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="CategorySave{TActivityData}" /> class.</summary>
        public CategorySave(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual saving of the <see cref="Category" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that deletes a <see cref="DomainModel.Category" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class CategoryDelete<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ICategoryContainer
    {

        /// <summary>Initializes a new instance of the <see cref="CategoryDelete{TActivityData}" /> class.</summary>
        public CategoryDelete(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="CategoryDelete{TActivityData}" /> class.</summary>
        public CategoryDelete(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual deletion of the <see cref="Category" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }

}
