﻿// $Id$

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Interface implemented by a class that acts as a <see cref="DomainModel.Customer" /> question factory.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial interface ICustomerCrudQuestionFactory
    {
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that initializes a new <see cref="DomainModel.Customer" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class CustomerCreate<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ICustomerContainer
    {

        /// <summary>Initializes a new instance of the <see cref="CustomerCreate{TActivityData}" /> class.</summary>
        public CustomerCreate(TActivityData data, IDataActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="CustomerCreate{TActivityData}" /> class.</summary>
        public CustomerCreate(TActivityData data, IDataActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual initialization of a new <see cref="Customer" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that asks information about a <see cref="DomainModel.Customer" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class CustomerAskInfos<TActivityData, TQuestionFactory>:
        QuestionActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ICustomerContainer
        where TQuestionFactory:
            ICustomerCrudQuestionFactory
    {

        /// <summary>Initializes a new instance of the <see cref="CustomerAskInfos{TActivityData}" /> class.</summary>
        public CustomerAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="CustomerAskInfos{TActivityData}" /> class.</summary>
        public CustomerAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        protected override void OnInitialized(ActivityStateEventArgs e)
        {
            _OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that saves a <see cref="DomainModel.Customer" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class CustomerSave<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ICustomerContainer
    {

        /// <summary>Initializes a new instance of the <see cref="CustomerSave{TActivityData}" /> class.</summary>
        public CustomerSave(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="CustomerSave{TActivityData}" /> class.</summary>
        public CustomerSave(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual saving of the <see cref="Customer" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that deletes a <see cref="DomainModel.Customer" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class CustomerDelete<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ICustomerContainer
    {

        /// <summary>Initializes a new instance of the <see cref="CustomerDelete{TActivityData}" /> class.</summary>
        public CustomerDelete(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="CustomerDelete{TActivityData}" /> class.</summary>
        public CustomerDelete(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual deletion of the <see cref="Customer" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }

}
