//$Id$

using System;
using System.Collections.Generic;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    partial interface IEmployeeCrudQuestionFactory
    {

        /// <summary>Gets a question about a <see cref="DomainModel.Employee" /> instance.</summary>
        Question AskEmployeeInfos(ActivityController controller, DomainModel.Employee domainModel);
    }



    partial class EmployeeCreate<TActivityData>
    {

        /// <summary>Performs the actual initialization of a new <see cref="DomainModel.Employee" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Employee=new DomainModel.Employee(((IDataActivityParameters)Parameters).DataMappers);
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class EmployeeAskInfos<TActivityData, TQuestionFactory>
    {

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        private void _OnInitialized(ActivityStateEventArgs e)
        {
            Question=((IQuestionFactoryParameters<TQuestionFactory>)Parameters).QuestionFactory.AskEmployeeInfos((ActivityController)e.Controller, Data.Employee);
            base.OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class EmployeeSave<TActivityData>
    {

        /// <summary>Performs the actual saving of the <see cref="DomainModel.Employee" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Employee.Save();
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class EmployeeDelete<TActivityData>
    {

        /// <summary>Performs the actual deletion of the <see cref="DomainModel.Employee" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Employee.Delete();
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }

}
