﻿// $Id$

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Interface implemented by a class that acts as a <see cref="DomainModel.Employee" /> question factory.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial interface IEmployeeCrudQuestionFactory
    {
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that initializes a new <see cref="DomainModel.Employee" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class EmployeeCreate<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IEmployeeContainer
    {

        /// <summary>Initializes a new instance of the <see cref="EmployeeCreate{TActivityData}" /> class.</summary>
        public EmployeeCreate(TActivityData data, IDataActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="EmployeeCreate{TActivityData}" /> class.</summary>
        public EmployeeCreate(TActivityData data, IDataActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual initialization of a new <see cref="Employee" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that asks information about a <see cref="DomainModel.Employee" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class EmployeeAskInfos<TActivityData, TQuestionFactory>:
        QuestionActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IEmployeeContainer
        where TQuestionFactory:
            IEmployeeCrudQuestionFactory
    {

        /// <summary>Initializes a new instance of the <see cref="EmployeeAskInfos{TActivityData}" /> class.</summary>
        public EmployeeAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="EmployeeAskInfos{TActivityData}" /> class.</summary>
        public EmployeeAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        protected override void OnInitialized(ActivityStateEventArgs e)
        {
            _OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that saves a <see cref="DomainModel.Employee" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class EmployeeSave<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IEmployeeContainer
    {

        /// <summary>Initializes a new instance of the <see cref="EmployeeSave{TActivityData}" /> class.</summary>
        public EmployeeSave(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="EmployeeSave{TActivityData}" /> class.</summary>
        public EmployeeSave(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual saving of the <see cref="Employee" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that deletes a <see cref="DomainModel.Employee" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class EmployeeDelete<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IEmployeeContainer
    {

        /// <summary>Initializes a new instance of the <see cref="EmployeeDelete{TActivityData}" /> class.</summary>
        public EmployeeDelete(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="EmployeeDelete{TActivityData}" /> class.</summary>
        public EmployeeDelete(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual deletion of the <see cref="Employee" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }

}
