//$Id$

using System;
using System.Collections.Generic;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    partial interface IOrderCrudQuestionFactory
    {

        /// <summary>Gets a question about a <see cref="DomainModel.Order" /> instance.</summary>
        Question AskOrderInfos(ActivityController controller, DomainModel.Order domainModel);
    }



    partial class OrderCreate<TActivityData>
    {

        /// <summary>Performs the actual initialization of a new <see cref="DomainModel.Order" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Order=new DomainModel.Order(((IDataActivityParameters)Parameters).DataMappers);
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class OrderAskInfos<TActivityData, TQuestionFactory>
    {

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        private void _OnInitialized(ActivityStateEventArgs e)
        {
            Question=((IQuestionFactoryParameters<TQuestionFactory>)Parameters).QuestionFactory.AskOrderInfos((ActivityController)e.Controller, Data.Order);
            base.OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class OrderSave<TActivityData>
    {

        /// <summary>Performs the actual saving of the <see cref="DomainModel.Order" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Order.Save();
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class OrderDelete<TActivityData>
    {

        /// <summary>Performs the actual deletion of the <see cref="DomainModel.Order" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Order.Delete();
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }

}
