﻿// $Id$

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Interface implemented by a class that acts as a <see cref="DomainModel.OrderDetails" /> question factory.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial interface IOrderDetailsCrudQuestionFactory
    {
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that initializes a new <see cref="DomainModel.OrderDetails" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class OrderDetailsCreate<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IOrderDetailsContainer
    {

        /// <summary>Initializes a new instance of the <see cref="OrderDetailsCreate{TActivityData}" /> class.</summary>
        public OrderDetailsCreate(TActivityData data, IDataActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="OrderDetailsCreate{TActivityData}" /> class.</summary>
        public OrderDetailsCreate(TActivityData data, IDataActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual initialization of a new <see cref="OrderDetails" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that asks information about a <see cref="DomainModel.OrderDetails" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class OrderDetailsAskInfos<TActivityData, TQuestionFactory>:
        QuestionActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IOrderDetailsContainer
        where TQuestionFactory:
            IOrderDetailsCrudQuestionFactory
    {

        /// <summary>Initializes a new instance of the <see cref="OrderDetailsAskInfos{TActivityData}" /> class.</summary>
        public OrderDetailsAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="OrderDetailsAskInfos{TActivityData}" /> class.</summary>
        public OrderDetailsAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        protected override void OnInitialized(ActivityStateEventArgs e)
        {
            _OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that saves a <see cref="DomainModel.OrderDetails" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class OrderDetailsSave<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IOrderDetailsContainer
    {

        /// <summary>Initializes a new instance of the <see cref="OrderDetailsSave{TActivityData}" /> class.</summary>
        public OrderDetailsSave(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="OrderDetailsSave{TActivityData}" /> class.</summary>
        public OrderDetailsSave(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual saving of the <see cref="OrderDetails" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that deletes a <see cref="DomainModel.OrderDetails" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class OrderDetailsDelete<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IOrderDetailsContainer
    {

        /// <summary>Initializes a new instance of the <see cref="OrderDetailsDelete{TActivityData}" /> class.</summary>
        public OrderDetailsDelete(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="OrderDetailsDelete{TActivityData}" /> class.</summary>
        public OrderDetailsDelete(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual deletion of the <see cref="OrderDetails" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }

}
