//$Id$

using System;
using System.Collections.Generic;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    partial interface IProductCrudQuestionFactory
    {

        /// <summary>Gets a question about a <see cref="DomainModel.Product" /> instance.</summary>
        Question AskProductInfos(ActivityController controller, DomainModel.Product domainModel);
    }



    partial class ProductCreate<TActivityData>
    {

        /// <summary>Performs the actual initialization of a new <see cref="DomainModel.Product" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Product=new DomainModel.Product(((IDataActivityParameters)Parameters).DataMappers);
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class ProductAskInfos<TActivityData, TQuestionFactory>
    {

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        private void _OnInitialized(ActivityStateEventArgs e)
        {
            Question=((IQuestionFactoryParameters<TQuestionFactory>)Parameters).QuestionFactory.AskProductInfos((ActivityController)e.Controller, Data.Product);
            base.OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class ProductSave<TActivityData>
    {

        /// <summary>Performs the actual saving of the <see cref="DomainModel.Product" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Product.Save();
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class ProductDelete<TActivityData>
    {

        /// <summary>Performs the actual deletion of the <see cref="DomainModel.Product" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Product.Delete();
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }

}
