﻿// $Id$

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Interface implemented by a class that acts as a <see cref="DomainModel.Product" /> question factory.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial interface IProductCrudQuestionFactory
    {
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that initializes a new <see cref="DomainModel.Product" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class ProductCreate<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IProductContainer
    {

        /// <summary>Initializes a new instance of the <see cref="ProductCreate{TActivityData}" /> class.</summary>
        public ProductCreate(TActivityData data, IDataActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="ProductCreate{TActivityData}" /> class.</summary>
        public ProductCreate(TActivityData data, IDataActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual initialization of a new <see cref="Product" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that asks information about a <see cref="DomainModel.Product" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class ProductAskInfos<TActivityData, TQuestionFactory>:
        QuestionActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IProductContainer
        where TQuestionFactory:
            IProductCrudQuestionFactory
    {

        /// <summary>Initializes a new instance of the <see cref="ProductAskInfos{TActivityData}" /> class.</summary>
        public ProductAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="ProductAskInfos{TActivityData}" /> class.</summary>
        public ProductAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        protected override void OnInitialized(ActivityStateEventArgs e)
        {
            _OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that saves a <see cref="DomainModel.Product" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class ProductSave<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IProductContainer
    {

        /// <summary>Initializes a new instance of the <see cref="ProductSave{TActivityData}" /> class.</summary>
        public ProductSave(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="ProductSave{TActivityData}" /> class.</summary>
        public ProductSave(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual saving of the <see cref="Product" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that deletes a <see cref="DomainModel.Product" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class ProductDelete<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            IProductContainer
    {

        /// <summary>Initializes a new instance of the <see cref="ProductDelete{TActivityData}" /> class.</summary>
        public ProductDelete(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="ProductDelete{TActivityData}" /> class.</summary>
        public ProductDelete(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual deletion of the <see cref="Product" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }

}
