//$Id$

using System;
using System.Collections.Generic;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    partial interface IShipperCrudQuestionFactory
    {

        /// <summary>Gets a question about a <see cref="DomainModel.Shipper" /> instance.</summary>
        Question AskShipperInfos(ActivityController controller, DomainModel.Shipper domainModel);
    }



    partial class ShipperCreate<TActivityData>
    {

        /// <summary>Performs the actual initialization of a new <see cref="DomainModel.Shipper" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Shipper=new DomainModel.Shipper(((IDataActivityParameters)Parameters).DataMappers);
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class ShipperAskInfos<TActivityData, TQuestionFactory>
    {

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        private void _OnInitialized(ActivityStateEventArgs e)
        {
            Question=((IQuestionFactoryParameters<TQuestionFactory>)Parameters).QuestionFactory.AskShipperInfos((ActivityController)e.Controller, Data.Shipper);
            base.OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class ShipperSave<TActivityData>
    {

        /// <summary>Performs the actual saving of the <see cref="DomainModel.Shipper" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Shipper.Save();
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }



    partial class ShipperDelete<TActivityData>
    {

        /// <summary>Performs the actual deletion of the <see cref="DomainModel.Shipper" /> instance.</summary>
        private ActivityStateResult _Handle(IActivityController controller)
        {
            Data.Shipper.Delete();
            return ActivityStateResult.Next;
        }

        /// <summary>Gets the next state.</summary>
        private ActivityState<TActivityData> _NextState
        {
            get
            {
                if (_NextStateCreator!=null)
                    return _NextStateCreator(Data, Parameters);

                return new EndActivityState<TActivityData>(Data);
            }
        }

        private NextStateCreateHandler<TActivityData> _NextStateCreator;
    }

}
