﻿// $Id$

using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using Salamanca;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataActivities;
using Salamanca.DataActivities.UI;
using Salamanca.DataRules;

namespace Northwind.DomainModel.Activities
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Interface implemented by a class that acts as a <see cref="DomainModel.Supplier" /> question factory.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial interface ISupplierCrudQuestionFactory
    {
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that initializes a new <see cref="DomainModel.Supplier" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class SupplierCreate<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ISupplierContainer
    {

        /// <summary>Initializes a new instance of the <see cref="SupplierCreate{TActivityData}" /> class.</summary>
        public SupplierCreate(TActivityData data, IDataActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="SupplierCreate{TActivityData}" /> class.</summary>
        public SupplierCreate(TActivityData data, IDataActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual initialization of a new <see cref="Supplier" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that asks information about a <see cref="DomainModel.Supplier" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class SupplierAskInfos<TActivityData, TQuestionFactory>:
        QuestionActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ISupplierContainer
        where TQuestionFactory:
            ISupplierCrudQuestionFactory
    {

        /// <summary>Initializes a new instance of the <see cref="SupplierAskInfos{TActivityData}" /> class.</summary>
        public SupplierAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="SupplierAskInfos{TActivityData}" /> class.</summary>
        public SupplierAskInfos(TActivityData data, IQuestionFactoryParameters<TQuestionFactory> parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Raises the <see cref="ActivityState{TActivityData}.Initialized" /> event.</summary>
        protected override void OnInitialized(ActivityStateEventArgs e)
        {
            _OnInitialized(e);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that saves a <see cref="DomainModel.Supplier" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class SupplierSave<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ISupplierContainer
    {

        /// <summary>Initializes a new instance of the <see cref="SupplierSave{TActivityData}" /> class.</summary>
        public SupplierSave(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="SupplierSave{TActivityData}" /> class.</summary>
        public SupplierSave(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual saving of the <see cref="Supplier" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary>Activity state that deletes a <see cref="DomainModel.Supplier" /> instance.</summary>
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class SupplierDelete<TActivityData>:
        ActivityState<TActivityData>
        where TActivityData:
            IActivityData,
            ISupplierContainer
    {

        /// <summary>Initializes a new instance of the <see cref="SupplierDelete{TActivityData}" /> class.</summary>
        public SupplierDelete(TActivityData data, IActivityParameters parameters):
            this(data, parameters, null)
        {
        }

        /// <summary>Initializes a new instance of the <see cref="SupplierDelete{TActivityData}" /> class.</summary>
        public SupplierDelete(TActivityData data, IActivityParameters parameters, NextStateCreateHandler<TActivityData> nextStateCreator):
            base(data, parameters)
        {
            _NextStateCreator=nextStateCreator;
        }

        /// <summary>Performs the actual deletion of the <see cref="Supplier" /> instance.</summary>
        protected override ActivityStateResult Handle(IActivityController controller)
        {
            return _Handle(controller);
        }

        /// <summary>Gets the next state.</summary>
        protected override IActivityState NextState
        {
            get
            {
                return _NextState;
            }
        }
    }

}
