﻿// $Id: OrderMapper.cs 17434 2008-12-01 12:48:12Z unknown $
/*! \file
 * \brief Definition of Northwind.DomainModel.Data.OrderMapper.
 *
 * \author $Author: unknown $
 * \date $Date: 2008-12-01 04:48:12 -0800 (周一, 01 十二月 2008) $
 * \version $Revision: 17434 $
 */

using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using System.Globalization;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataAccess.Data;

namespace Northwind.DomainModel.Data
{



    ///////////////////////////////////////////////////////////////////////////
    ///
    /// <summary />
    ///
    ///////////////////////////////////////////////////////////////////////////

    public partial class OrderMapper:
        DataMapper<Order, Order.PrimaryKey, Order.DataTransfer>,
        IOrderMapper
    {

        /// <summary />
        public OrderMapper(DbConnection connection, ICacheManager cacheManager):
            base(connection, DomainEntityCreator.CreateDefault<Order>(), cacheManager)
        {
            _ParameterBuilder=new ParameterBuilder(connection);
        }

        /// <summary />
        public DomainEntityKeyedCollection<Order> FindAll(DataMapperCollection dataMappers)
        {
          return _FindAll(dataMappers);
        }

        /// <summary />
        public DomainEntityKeyedCollection<Order> FindByCustomer(Customer customer, DataMapperCollection dataMappers)
        {
            IDbCommand[] commands=new IDbCommand[1];

            commands[0]=Connection.CreateCommand();
            commands[0].CommandType=CommandType.Text;
            commands[0].CommandText=string.Format(
                CultureInfo.InvariantCulture,
                Resources.Sql.OrderSelectByCustomer,
                ParameterBuilder.GetMarker("CustomerID", 1)
            );

            IDbDataParameter p=commands[0].CreateParameter();
            p.ParameterName=ParameterBuilder.GetName("CustomerID", 1);
            p.DbType=DbType.String;
            p.Value=customer.GetId().Value;
            p.Size=customer.GetId().Value.Length;
            p.Direction=ParameterDirection.Input;
            commands[0].Parameters.Add(p);

            return Load(commands, dataMappers);
        }

        /// <summary />
        protected override IList<IDbCommand> CreateSelectCommands(Order.PrimaryKey key)
        {
            return CreateSelectCommands(Connection, ParameterBuilder, key);
        }

        /// <summary />
        protected override IList<IDbCommand> CreateDeleteCommands(Order.DataTransfer data)
        {
            return CreateDeleteCommands(Connection, ParameterBuilder, (Order.DataTransfer)data);
        }

        /// <summary />
        protected override IList<IDbCommand> CreateInsertCommands(Order.DataTransfer data)
        {
            return CreateInsertCommands(Connection, ParameterBuilder, (Order.DataTransfer)data);
        }

        /// <summary />
        protected override IList<IDbCommand> CreateUpdateCommands(Order.DataTransfer data)
        {
            return CreateUpdateCommands(Connection, ParameterBuilder, (Order.DataTransfer)data);
        }

        /// <summary />
        protected override Order.DataTransfer GetDataTransferObject(IList<IDataRecord> records)
        {
          return _GetDataTransferObject(records);
        }

        /// <summary />
        protected override void OnInserted(Order domainModel, IList<IDbCommand> commands)
        {
            domainModel.SetId(Utils.GetLastId(Connection, commands));

            base.OnInserted(domainModel, commands);
        }

        /// <summary />
        internal static IList<IDbCommand> CreateSelectCommands(IDbConnection connection, ParameterBuilder parameterBuilder, Order.PrimaryKey key)
        {
            return new IDbCommand[] { _CreateSelectCommand(connection, parameterBuilder, key) };
        }

        /// <summary />
        internal static IList<IDbCommand> CreateDeleteCommands(IDbConnection connection, ParameterBuilder parameterBuilder, Order.DataTransfer data)
        {
            return new IDbCommand[] { _CreateDeleteCommand(connection, parameterBuilder, (Order.DataTransfer)data) };
        }

        /// <summary />
        internal static IList<IDbCommand> CreateInsertCommands(IDbConnection connection, ParameterBuilder parameterBuilder, Order.DataTransfer data)
        {
            return new IDbCommand[] { _CreateInsertCommand(connection, parameterBuilder, (Order.DataTransfer)data) };
        }

        /// <summary />
        internal static IList<IDbCommand> CreateUpdateCommands(IDbConnection connection, ParameterBuilder parameterBuilder, Order.DataTransfer data)
        {
            return new IDbCommand[] { _CreateUpdateCommand(connection, parameterBuilder, (Order.DataTransfer)data) };
        }

    }
}
