// $Id: SupplierMapper.Model.cs 17434 2008-12-01 12:48:12Z unknown $
using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Common;
using System.Globalization;
using Microsoft.Practices.EnterpriseLibrary.Data;
using Salamanca.DataAccess;
using Salamanca.DataAccess.Collections;
using Salamanca.DataAccess.EnterpriseLibrary.Data;

namespace Northwind.DomainModel.EnterpriseLibrary
{

    /// <summary />
    partial class SupplierMapper
    {

        /// <summary />
        static SupplierMapper()
        {
            Resources.Sql.Culture=CultureInfo.InvariantCulture;
        }

        /// <summary />
        private DomainEntityKeyedCollection<Supplier> _FindAll(DataMapperCollection dataMappers)
        {
            DbCommand[] commands=new DbCommand[1];

            commands[0]=Database.GetSqlStringCommand(Resources.Sql.SupplierSelectAll);

            return Load(commands, dataMappers);
        }

        private Supplier.DataTransfer _GetDataTransferObject(IList<IDataRecord> records)
        {
            Supplier.DataTransfer data=new Supplier.DataTransfer();

            return FillData(data, records[0]);
        }

        /// <summary />
        internal static Supplier.DataTransfer FillData(Supplier.DataTransfer data, IDataRecord record)
        {
            int ord=record.GetOrdinal("SupplierID");
            if (!record.IsDBNull(ord))
                data.SupplierID=record.GetInt32(ord);

            ord=record.GetOrdinal("CompanyName");
            if (!record.IsDBNull(ord))
                data.CompanyName=record.GetString(ord);

            ord=record.GetOrdinal("ContactName");
            if (!record.IsDBNull(ord))
                data.ContactName=record.GetString(ord);

            ord=record.GetOrdinal("ContactTitle");
            if (!record.IsDBNull(ord))
                data.ContactTitle=record.GetString(ord);

            ord=record.GetOrdinal("Address");
            if (!record.IsDBNull(ord))
                data.Address=record.GetString(ord);

            ord=record.GetOrdinal("City");
            if (!record.IsDBNull(ord))
                data.City=record.GetString(ord);

            ord=record.GetOrdinal("Region");
            if (!record.IsDBNull(ord))
                data.Region=record.GetString(ord);

            ord=record.GetOrdinal("PostalCode");
            if (!record.IsDBNull(ord))
                data.PostalCode=record.GetString(ord);

            ord=record.GetOrdinal("Country");
            if (!record.IsDBNull(ord))
                data.Country=record.GetString(ord);

            ord=record.GetOrdinal("Phone");
            if (!record.IsDBNull(ord))
                data.Phone=record.GetString(ord);

            ord=record.GetOrdinal("Fax");
            if (!record.IsDBNull(ord))
                data.Fax=record.GetString(ord);

            ord=record.GetOrdinal("HomePage");
            if (!record.IsDBNull(ord))
                data.HomePage=record.GetString(ord);

            return data;
        }

        /// <summary />
        private static DbCommand _CreateSelectCommand(Database database, Salamanca.DataAccess.Data.ParameterBuilder parameterBuilder, Supplier.PrimaryKey key)
        {
            DbCommand command=database.GetSqlStringCommand(
                string.Format(
                    CultureInfo.InvariantCulture,
                    Resources.Sql.SupplierSelect,
                    parameterBuilder.GetMarker("SupplierID", 1)
                )
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("SupplierID", 1),
                DbType.Int32,
                ParameterDirection.Input,
                string.Empty,
                DataRowVersion.Default,
                key.Value
            );

            return command;
        }

        /// <summary />
        private static DbCommand _CreateDeleteCommand(Database database, Salamanca.DataAccess.Data.ParameterBuilder parameterBuilder, Supplier.DataTransfer data)
        {
            DbCommand command=database.GetSqlStringCommand(
                string.Format(
                    CultureInfo.InvariantCulture,
                    Resources.Sql.SupplierDelete,
                    parameterBuilder.GetMarker("SupplierID", 1)
                )
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("SupplierID", 1),
                DbType.Int32,
                ParameterDirection.Input,
                string.Empty,
                DataRowVersion.Default,
                data.SupplierID
            );

            return command;
        }

        /// <summary />
        private static DbCommand _CreateInsertCommand(Database database, Salamanca.DataAccess.Data.ParameterBuilder parameterBuilder, Supplier.DataTransfer data)
        {
            DbCommand command=database.GetSqlStringCommand(
                string.Format(
                    CultureInfo.InvariantCulture,
                    Resources.Sql.SupplierInsert,
                    parameterBuilder.GetMarker("CompanyName", 1),
                    parameterBuilder.GetMarker("ContactName", 2),
                    parameterBuilder.GetMarker("ContactTitle", 3),
                    parameterBuilder.GetMarker("Address", 4),
                    parameterBuilder.GetMarker("City", 5),
                    parameterBuilder.GetMarker("Region", 6),
                    parameterBuilder.GetMarker("PostalCode", 7),
                    parameterBuilder.GetMarker("Country", 8),
                    parameterBuilder.GetMarker("Phone", 9),
                    parameterBuilder.GetMarker("Fax", 10),
                    parameterBuilder.GetMarker("HomePage", 11)
                )
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("CompanyName", 1),
                DbType.String,
                40,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                data.CompanyName
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("ContactName", 2),
                DbType.String,
                30,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.ContactName ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("ContactTitle", 3),
                DbType.String,
                30,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.ContactTitle ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("Address", 4),
                DbType.String,
                60,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.Address ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("City", 5),
                DbType.String,
                15,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.City ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("Region", 6),
                DbType.String,
                15,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.Region ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("PostalCode", 7),
                DbType.String,
                10,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.PostalCode ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("Country", 8),
                DbType.String,
                15,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.Country ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("Phone", 9),
                DbType.String,
                24,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.Phone ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("Fax", 10),
                DbType.String,
                24,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.Fax ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("HomePage", 11),
                DbType.String,
                8192,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.HomePage ?? (object)DBNull.Value
            );

            return command;
        }

        /// <summary />
        private static DbCommand _CreateUpdateCommand(Database database, Salamanca.DataAccess.Data.ParameterBuilder parameterBuilder, Supplier.DataTransfer data)
        {
            DbCommand command=database.GetSqlStringCommand(
                string.Format(
                    CultureInfo.InvariantCulture,
                    Resources.Sql.SupplierUpdate,
                    parameterBuilder.GetMarker("CompanyName", 1),
                    parameterBuilder.GetMarker("ContactName", 2),
                    parameterBuilder.GetMarker("ContactTitle", 3),
                    parameterBuilder.GetMarker("Address", 4),
                    parameterBuilder.GetMarker("City", 5),
                    parameterBuilder.GetMarker("Region", 6),
                    parameterBuilder.GetMarker("PostalCode", 7),
                    parameterBuilder.GetMarker("Country", 8),
                    parameterBuilder.GetMarker("Phone", 9),
                    parameterBuilder.GetMarker("Fax", 10),
                    parameterBuilder.GetMarker("HomePage", 11),
                    parameterBuilder.GetMarker("SupplierID", 12)
                )
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("CompanyName", 1),
                DbType.String,
                40,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                data.CompanyName
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("ContactName", 2),
                DbType.String,
                30,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.ContactName ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("ContactTitle", 3),
                DbType.String,
                30,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.ContactTitle ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("Address", 4),
                DbType.String,
                60,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.Address ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("City", 5),
                DbType.String,
                15,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.City ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("Region", 6),
                DbType.String,
                15,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.Region ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("PostalCode", 7),
                DbType.String,
                10,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.PostalCode ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("Country", 8),
                DbType.String,
                15,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.Country ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("Phone", 9),
                DbType.String,
                24,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.Phone ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("Fax", 10),
                DbType.String,
                24,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.Fax ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("HomePage", 11),
                DbType.String,
                8192,
                ParameterDirection.Input,
                false,
                0,
                0,
                string.Empty,
                DataRowVersion.Default,
                (object)data.HomePage ?? (object)DBNull.Value
            );

            database.AddParameter(
                command,
                parameterBuilder.GetName("SupplierID", 12),
                DbType.Int32,
                ParameterDirection.Input,
                string.Empty,
                DataRowVersion.Default,
                data.SupplierID
            );

            return command;
        }

        /// <summary>Gets the parameter builder instance.</summary>
        /// <value>The parameter builder instance.</value>
        protected Salamanca.DataAccess.Data.ParameterBuilder ParameterBuilder
        {
            get
            {
                return _ParameterBuilder;
            }
        }

        private Salamanca.DataAccess.Data.ParameterBuilder _ParameterBuilder;

    }

}
