﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using DslModeling=global::Microsoft.VisualStudio.Modeling;

namespace Salamanca.Saml
{



    /// <summary>Type converter that provides a list of values to be displayed to select the <see cref="QuestionState.DataName" /> of an <see cref="QuestionState" />.</summary>
    public class DataNameConverter:
        TypeConverter
    {

        /// <summary>Returns <c>true</c> to indicate that we return a list of values to choose from.</summary>
        public override bool GetStandardValuesSupported(ITypeDescriptorContext context)
        {
            return true;
        }

        /// <summary>Returns <c>true</c> to indicate that the user has to select a value from the list.</summary>
        /// <returns><c>true</c>. If we returned <c>false</c>, the user would be able to either select a value from 
        /// the list or type in a value that is not in the list.</returns>
        public override bool GetStandardValuesExclusive(ITypeDescriptorContext context)
        {
            return true;
        }

        /// <summary>Returns a list of the values to display in the grid.</summary>
        /// <returns>A list of values the user can choose from.</returns>
        public override StandardValuesCollection GetStandardValues(ITypeDescriptorContext context)
        {
            // Try to get a store from the current context
            // "context.Instance"  returns the element(s) that are currently selected i.e. whose values are being
            // shown in the property grid. Note that the user could have selected multiple objects, in which case 
            // context.Instance will be an array.
            DslModeling.Store store=GetStore(context.Instance);

            return new StandardValuesCollection((ICollection)GetNames(store));
        }

        /// <summary>Attempts to get to a store from the currently selected object(s) in the property grid.</summary>
        private DslModeling.Store GetStore(object gridSelection)
        {
            // We assume that "instance" will either be a single model element, or 
            // an array of model elements (if multiple items are selected).
            DslModeling.ModelElement currentElement=null;

            object[] objects=gridSelection as object[];
            if ((objects!=null)&&(objects.Length>0))
                currentElement=objects[0] as DslModeling.ModelElement;
            else
                currentElement=gridSelection as DslModeling.ModelElement;

            return (currentElement==null) ? null : currentElement.Store;
        }

        /// <summary>Returns a list of all the valid names in the specified <paramref name="store" />.</summary>
        internal static IList<string> GetNames(DslModeling.Store store)
        {
            if (store==null)
                return new string[] { };

            List<string> ret=new List<string>();

            // Add all enumerations names
            ret.AddRange(store.ElementDirectory.FindElements<DataAttribute>().Select<DataAttribute, string>(a => a.Name));
            ret.Sort();

            return ret;
        }
    }

}
