@ECHO OFF
::--------------------------------------------------------------------
:: Usage: "build [/clean | /rebuild | /doc | /release] [/vs] [/NoPause]"
::
::                 /clean   - Cleans the project
::                 /rebuild - Cleans and builds the project (default)
::                 /doc     - Creates the documentation for the project
::                 /release - Builds a release version of the project
::
::                 /vs      - Uses the Visual Studio 2008 environment
::
::                 /NoPause - Does not pause after completion
::--------------------------------------------------------------------



SETLOCAL
SET NO_PAUSE=0
SET ENV=
SET TARGET=Rebuild
GOTO ARGS



:: -------------------------------------------------------------------
:: Builds the project
:: -------------------------------------------------------------------
:BUILD
msbuild Libraries.msbuild /nologo /t:%TARGET% /m:%NUMBER_OF_PROCESSORS% /l:FileLogger,Microsoft.Build.Engine;logfile=build.libraries.log;verbosity=minimal;encoding=UTF-8 /l:FileLogger,Microsoft.Build.Engine;logfile=build.libraries.detailed.log;verbosity=detailed;encoding=UTF-8
IF ERRORLEVEL 1 (
    msbuild misc\Result.msbuild /t:Failure /nologo /noconlog /v:q
    GOTO END
)

msbuild Factory.msbuild /nologo /t:%TARGET% /m:%NUMBER_OF_PROCESSORS% /l:FileLogger,Microsoft.Build.Engine;logfile=build.factory.log;verbosity=minimal;encoding=UTF-8 /l:FileLogger,Microsoft.Build.Engine;logfile=build.factory.detailed.log;verbosity=detailed;encoding=UTF-8
IF ERRORLEVEL 1 (
    msbuild misc\Result.msbuild /t:Failure /nologo /noconlog /v:q
) ELSE (
    msbuild misc\Result.msbuild /t:Success /nologo /noconlog /v:q
)
GOTO END



:: -------------------------------------------------------------------
:: Parse command line argument values
:: Note: Currently, last one on the command line wins (ex: /nsdk /wsdk)
:: -------------------------------------------------------------------
:ARGS
IF NOT "x%~4"=="x" GOTO ERROR_USAGE

:ARGS_PARSE
IF /I "%~1"=="/clean"      SET TARGET=Clean& SHIFT & GOTO ARGS_PARSE
IF /I "%~1"=="/rebuild"    SET TARGET=Rebuild& SHIFT & GOTO ARGS_PARSE
IF /I "%~1"=="/doc"        SET TARGET=Document& SHIFT & GOTO ARGS_PARSE
IF /I "%~1"=="/release"    SET TARGET=Release& SHIFT & GOTO ARGS_PARSE
IF /I "%~1"=="/vs"         SET ENV=VS& SHIFT & GOTO ARGS_PARSE
IF /I "%~1"=="/NoPause"    SET NO_PAUSE=1& SHIFT & GOTO ARGS_PARSE
IF /I "%~1"=="-h"          GOTO ERROR_USAGE
IF /I "%~1"=="/?"          GOTO ERROR_USAGE
IF    "%~1" EQU ""         GOTO ARGS_DONE
ECHO Unknown command-line switch: %~1
GOTO ERROR_USAGE

:ARGS_DONE
GOTO SETENV



:: -------------------------------------------------------------------
:: Set environment variables
:: -------------------------------------------------------------------
:SETENV
SET PATH="%CD%\misc\Tools\";%PATH%

IF "x%ENV%x"=="xx" GOTO SETENV_DEFAULT
IF "%ENV%"=="VS" (
    IF EXIST "%VS90COMNTOOLS%\vsvars32.bat" GOTO SETENV_VS
    GOTO ERROR_NOSDK
)

:SETENV_DEFAULT
IF EXIST "%VS90COMNTOOLS%\vsvars32.bat" GOTO SETENV_VS
GOTO ERROR_NOSDK

:SETENV_VS
CALL "%VS90COMNTOOLS%\vsvars32.bat"
::IF ERRORLEVEL 1 GOTO ERROR_NOVS90
GOTO BUILD



:: -------------------------------------------------------------------
:: Errors
:: -------------------------------------------------------------------

:ERROR_NOVS90
ECHO Visual Studio 2008 could not be found.
ECHO.
ECHO Please make sure that :
ECHO   * Visual Studio 2008 is installed
ECHO   * %%VS90COMNTOOLS%% is defined and correct (C:\Program Files\Microsoft Visual Studio 9.0\Common7\Tools\)
GOTO END

:ERROR_NOSDK
ECHO No proper SDK was found.
ECHO.
ECHO Please install at least one of the following :
ECHO   * Windows SDK
ECHO     - Make sure that %%WINDOWS_SDK_HOME%% is defined and correct (C:\Program Files\Microsoft SDKs\Windows\v6.1\Bin)
ECHO   * Visual Studio 2008
ECHO     - Make sure that %%VS90COMNTOOLS%% is defined and correct (C:\Program Files\Microsoft Visual Studio 9.0\Common7\Tools\)
GOTO END

:ERROR_EXT
ECHO Could not activate command extensions
GOTO END

:ERROR_USAGE
ECHO Usage: "build [/clean | /rebuild | /doc | /release] [/vs] [/NoPause]"
ECHO.
ECHO                 /clean   - Cleans the project
ECHO                 /rebuild - Cleans and builds the project (default)
ECHO                 /doc     - Creates the documentation for the project
ECHO                 /release - Builds a release version of the project
ECHO.
ECHO                 /vs      - Uses the Visual Studio 2008 environment
ECHO.
ECHO                 /NoPause - Does not pause after completion
GOTO END



:: -------------------------------------------------------------------
:: End
:: -------------------------------------------------------------------
:END
@IF NOT "%NO_PAUSE%"=="1" PAUSE
ENDLOCAL
